@@ -26,7 +26,7 @@ _CHARSET_RE = re.compile('^{}$'.format(CHARSET_REGEX))
 DATA_URI_REGEX = (
     r'data:' +
     r'(?P<mimetype>{})?'.format(MIMETYPE_REGEX) +
-    r'(?:\;name\=(?P<name>[\w\.\-%]+))?' +
+    r"(?:\;name\=(?P<name>[\w\.\-%!*'~\(\)]+))?" +
     r'(?:\;charset\=(?P<charset>{}))?'.format(CHARSET_REGEX) +
     r'(?P<base64>\;base64)?' +
     r',(?P<data>.*)')
@@ -78,7 +78,7 @@ class DataURI(str):
         return 'DataURI(%s)' % (super(DataURI, self).__repr__(),)
 
     def wrap(self, width=76):
-        return type(self)('\n'.join(textwrap.wrap(self, width)))
+        return '\n'.join(textwrap.wrap(self, width))
 
     @property
     def mimetype(self):
